@@ -1,3 +1,4 @@
+##version==0.0.6##
 class alphabet:
     def __init__(self,sym) -> None:
       self.sym=sym
@@ -390,23 +391,54 @@ class number:
 def help():
   print()
   print("*********************************************************")
-  print("This module has been written by Harsh Gupta.")
-  print("This module can be used to display the given input into figlet fonts :)\n")
+  print("This program has been written by Harsh Gupta.")
+  print("This program can be used to display the given input into figlet fonts :)\n")
   print("Syntax >>>myfiglet.display(<input string>,<symbol>)\n")
   print("For example.......")
   print(">>>myfiglet.display('Python','%')\n")
   print("OUTPUT:")
   display("Python",'%')
   print("For example.......")
-  print("TO PRINT FIGLET WITH SELF SMALL CHARACTERS USE: pattern='name'")
+  print("TO PRINT FIGLET WITH SELF BUILDING CHARACTERS USE: pattern='name'\n")
+  print("For example.......")
   print(">>>myfiglet.display('Python',pattern='name')")
+  print("OUTPUT:")
   display("Python",pattern="name")
-  print("Second argument '<symbol>' in dispaly() is optional and is by default '*'")
+  print("Second argument '<symbol>' in dispaly() is optional and is by default '*'\n")
+  print("IF YOU WANT TO ADD COLOURS TO YOUR FIGLET FONT : use <color> parameter ")
+  print("For example.......")
+  print(">>>myfiglet.display('Python','@',colour='red')")
+  print("OUTPUT:")
+  display("Python","@",colour='red')
+  print("TO DISPLAY BRIGHT COLOURS TYPE:")
+  print("   >>>myfiglet.display('Python','@',colour='yellow',bright=True)\n")
+  print("TO VIEW ALL AVAILABLE COLOUR SCHEMES TYPE:")
+  print("   >>>myfiglet.colour_help()\n")
+  print("TO ADD RAINBOW COLOUR EFFECT TO YOUR FIGLET TYPE:")
+  print("   >>>myfiglet.display('Python','@',rainbow=True)")
+  print("OUTPUT:")
+  display("Python","@",rainbow=True)
   print("*********************************************************")
 
+def colour_help():
+  print("|----------------------------------------------|")
+  print("|     colour=    |    CORRESPONDING COLOUR     |")
+  print("|----------------------------------------------|")
+  print("|     'black'    |        Dark Black           |")
+  print("|     'red'      |        Dark Red             |")
+  print("|     'green'    |        Dark Green           |")
+  print("|     'yellow'   |        Yellow               |")
+  print("|     'blue'     |        Blue                 |")
+  print("|     'magenta'  |        Dark Magenta         |")
+  print("|     'cyan'     |        Cyan                 |")
+  print("|     'white'    |        Pure White           |")
+  print("|----------------------------------------------|")
+
 class control:
   def main(obj_alph,obj_num,name):
     for i in range(0,5):
+      if rainbow_schema==1:
+        print(rainbow_colour[i],end="")
       for k in range(0,len(name)):
         if name[k]==' ':
           alphabet.space()
@@ -483,19 +515,37 @@ class control:
         elif name[k]=="8":
           number.eight_8(obj_num,i)
         elif name[k]=="9":
-          number.nine_9(obj_num,i)                                                                                 
-      print()  
+          number.nine_9(obj_num,i)                                                                                
+      print()
+      
 
-def display(name,symbol='*',pattern=None):
+reset='\u001b[0m'
+rainbow_colour={0:'\u001b[35m',1:'\u001b[34m',2:'\u001b[32m',3:'\u001b[33m',4:'\u001b[31m'}
+colour_scheme={'bright black':'\u001b[30;1m','bright red':'\u001b[31;1m','bright green':'\u001b[32;1m','bright yellow':'\u001b[33;1m','bright blue':'\u001b[34;1m','bright magenta':'\u001b[35;1m','bright cyan':'\u001b[36;1m','bright white':'\u001b[37;1m','black':'\u001b[30m','red':'\u001b[31m','green':'\u001b[32m','yellow':'\u001b[33m','blue':'\u001b[34m','magenta':'\u001b[35m','cyan':'\u001b[36m','white':'\u001b[37m'}
+def colour_check(colour,bright):
+  try:
+    if bright==True:
+      return colour_scheme['bright '+colour]
+    else:  
+      return colour_scheme[colour]
+  except:
+    return "You choose Invalid colour !!!\n"
+
+rainbow_schema=0
+def display(name,symbol='*',rainbow=False,pattern=None,colour=None,bright=False):
+  if rainbow==True:
+    global rainbow_schema
+    rainbow_schema=1
+  elif colour !=None:
+    print(colour_check(colour,bright))
   if pattern=="name":
-    print()
     alph=alphabet(None)
     num=alphabet(None)
     control.main(alph,num,name)
-    print()
+    print(reset)
   else:
-    print()
     alph=alphabet(symbol)
     num=alphabet(symbol)
     control.main(alph,num,name)
-    print()
+    print(reset)
+
